==> httpcomponents-client-5.1.4-src.zip: httpclient5-cache/src/test/java/org/apache/hc/client5/http/impl/cache/ResponseEquivalent.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */
package org.apache.hc.client5.http.impl.cache;

import org.apache.hc.core5.http.HttpResponse;
import org.easymock.IArgumentMatcher;

public class ResponseEquivalent implements IArgumentMatcher {

    private final HttpResponse expected;

    public ResponseEquivalent(final HttpResponse expected) {
        this.expected = expected;
    }

    @Override
    public boolean matches(final Object actual) {
        if (!(actual instanceof HttpResponse)) {
            return false;
        }
        final HttpResponse other = (HttpResponse) actual;
        return HttpTestUtils.equivalent(expected, other);
    }

    @Override
    public void appendTo(final StringBuffer buf) {
        buf.append("eqRequest(");
        buf.append(expected);
        buf.append(")");
    }

}

==> httpcomponents-client-5.5.1-src.zip: httpclient5-cache/src/test/java/org/apache/hc/client5/http/impl/cache/ResponseEquivalent.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */
package org.apache.hc.client5.http.impl.cache;

import org.apache.hc.core5.http.HttpResponse;
import org.mockito.ArgumentMatcher;
import org.mockito.ArgumentMatchers;

public class ResponseEquivalent<T extends HttpResponse> implements ArgumentMatcher<T> {

    private final T expected;

    public ResponseEquivalent(final T expected) {
        this.expected = expected;
    }

    @Override
    public boolean matches(final T argument) {
        if (argument == null) {
            return false;
        }
        return HttpTestUtils.equivalent(expected, argument);
    }

    public static <T extends HttpResponse> T eq(final T response) {
        return ArgumentMatchers.argThat(new ResponseEquivalent<>(response));
    }

}
